scipy.sparse.data
=================

.. automodule:: scipy.sparse.data

   
   
   .. rubric:: Functions

   .. autosummary::
   
      isscalarlike
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      spmatrix
   
   

   
   
   